@@ -4,8 +4,8 @@
 utils::globalVariables(c(
   "layer_index", "token_index",
   "SS", "p_values.x", "p_values.y", "words", "n.x", "n.y",
-  "addEqualNrNArows", "applysemrep", "single_wordembeddings_df", "Ndim",
-  "semanticrepresentation", "single_wordembeddings2",
+  "addEqualNrNArows", "applysemrep", "single_word_embeddings_df", "Ndim",
+  "semanticrepresentation", "single_word_embeddings2",
   "guide_legend", "Dim1", "data_train",
   "textTrainRandomForest", "textTrainCVpredictions", "textTrainCVpredictionsRF",
   "textCentrality", "textCentralityPlot", "textEmbed", "textEmbedLayersOutput", "id_nr",
@@ -19,11 +19,18 @@ utils::globalVariables(c(
   "n", "n1", "n1_e", "dot2", "adjusted_p_values.x", "dot.x", "plot_n_word_extreme",
   "plot_n_word_frequency", "plot_n_words_middle", "n_all.x", "adjusted_p_values.y", "dot.y",
   "n_all.y", "colour_categories", "scale_color_identity", "group", "x", "y", "fill",
-  "check_p_square", "check_p_x_neg", "check_p_x_pos", "check_extreme_max_x", "check_extreme_min_x", "check_extreme_frequency_x",
-  "check_middle_x", "check_p_y_neg", "check_p_y_pos", "check_extreme_max_y", "check_extreme_min_y", "check_extreme_frequency_y",
+  "check_p_square", "check_p_x_neg", "check_p_x_pos", "check_extreme_max_x",
+  "check_extreme_min_x", "check_extreme_frequency_x",
+  "check_middle_x", "check_p_y_neg", "check_p_y_pos", "check_extreme_max_y",
+  "check_extreme_min_y", "check_extreme_frequency_y",
   "check_middle_y", "extremes_all_x", "extremes_all_y",
   "hgTransformerGetEmbedding", "central_cosine",
   "Dim_PC1", "Dim_PC2", "check_extreme_frequency", "check_extreme_max_PC1",
   "check_extreme_max_PC2", "check_extreme_min_PC1", "check_extreme_min_PC2",
-  "check_middle_PC1", "check_middle_PC2"
+  "check_middle_PC1", "check_middle_PC2",
+  "corr_y1", "corr_y2", "splits", "word_data1", "word_data1_middle_x",
+  "word_data_extrem_max_PC1", "word_data_extrem_max_PC2",
+  "word_data_extrem_min_PC1", "word_data_extrem_min_PC2", "word_data_frequency", "n_g1.x", "n_g2.x",
+  "centrality", "projection", "superviced",
+  "x_plotted", "y_plotted", "mixture_mode", "penalty_mode"
 ))
