@@ -1,5 +1,4 @@
 
-#  devtools::document()
 #' Select evaluation measure and compute it (also used in logistic regression)
 #'
 #' @param eval_measure Measure used to evaluate and select models default: "roc_auc", see also
@@ -10,7 +9,10 @@
 #' @return  tibble with .metric column (i.e., type of evaluation measure), .estimator (e.g., binary)
 #' and .estimate (i.e., the resulting value).
 #' @noRd
-select_eval_measure_val <- function(eval_measure = "bal_accuracy", holdout_pred = NULL, truth = y, estimate = .pred_class, class) {
+select_eval_measure_val <- function(eval_measure = "bal_accuracy",
+                                    holdout_pred = NULL,
+                                    truth = y,
+                                    estimate = .pred_class, class) {
   # Get accuracy
   if (eval_measure == "accuracy") {
     eval_measure_val <- yardstick::accuracy(holdout_pred, truth = y, estimate = .pred_class)
@@ -33,8 +35,8 @@ select_eval_measure_val <- function(eval_measure = "bal_accuracy", holdout_pred
     eval_measure_val <- yardstick::rmse(holdout_pred, truth = y, estimate = .pred)
   } else if (eval_measure == "rsq") {
     eval_measure_val <- yardstick::rsq(holdout_pred, truth = y, estimate = .pred)
-  }  else if (eval_measure == "cor_test") {
-    cor_testing <- cor.test(holdout_pred$y, holdout_pred$.pred, na.action=na.omit)
+  } else if (eval_measure == "cor_test") {
+    cor_testing <- cor.test(holdout_pred$y, holdout_pred$.pred, na.action = na.omit)
     estimate1 <- cor_testing[[4]][[1]]
     metric <- "cor_test"
     estimator <- "standard"
@@ -44,7 +46,6 @@ select_eval_measure_val <- function(eval_measure = "bal_accuracy", holdout_pred
   eval_measure_val
 }
 
-#  devtools::document()
 #' Select evaluation measure and compute it (also used in logistic regression)
 #'
 #' @param outputlist_results_outer Results from outer predictions.
@@ -99,7 +100,6 @@ classification_results <- function(outputlist_results_outer, id_nr = NA, ...) {
   output
 }
 
-#  devtools::document()
 #' Function to fit a model and compute accuracy
 #'
 #' @param object An rsplit object (from results_nested_resampling tibble)
@@ -124,8 +124,7 @@ fit_model_accuracy_rf <- function(object,
                                   variable_name_index_pca = NA,
                                   eval_measure = "bal_accuracy",
                                   extremely_randomised_splitrule = NULL) {
-
-  data_train <- rsample::analysis(object)   # mdata_train <- rsample::assessment(object)
+  data_train <- rsample::analysis(object)
   data_train <- tibble::as_tibble(data_train)
 
   # Recipe for one embedding input
@@ -135,12 +134,12 @@ fit_model_accuracy_rf <- function(object,
       recipes::update_role(id_nr, new_role = "id variable") %>% # New
       recipes::update_role(-id_nr, new_role = "predictor") %>% # New
       recipes::update_role(y, new_role = "outcome") %>% # New
-      recipes::step_naomit(recipes::all_predictors(), skip = FALSE) #%>%
-      #recipes::step_BoxCox(recipes::all_predictors()) %>%
+      recipes::step_naomit(recipes::all_predictors(), skip = FALSE) # %>%
+    # recipes::step_BoxCox(recipes::all_predictors()) %>%
 
     if (preprocess_step_center) {
-        xy_recipe <- recipes::step_center(xy_recipe, recipes::all_predictors())
-      }
+      xy_recipe <- recipes::step_center(xy_recipe, recipes::all_predictors())
+    }
     if (preprocess_scale_center) {
       xy_recipe <- recipes::step_scale(xy_recipe, recipes::all_predictors())
     }
@@ -160,13 +159,11 @@ fit_model_accuracy_rf <- function(object,
         } else {
           .
         }
-      } #%>%
-      #recipes::prep()
+      }
     xy_recipe_prep <- recipes::prep(xy_recipe)
 
     # Recipe for multiple word embedding input (with possibility of separate PCAs)
   } else {
-    #V1 <- colnames(rsample::analysis(object)[1])
 
     xy_recipe <- rsample::analysis(object) %>%
       recipes::recipe(y ~ .) %>%
@@ -197,24 +194,20 @@ fit_model_accuracy_rf <- function(object,
         }
       }
     }
-   xy_recipe_prep <- recipes::prep(xy_recipe)
+    xy_recipe_prep <- recipes::prep(xy_recipe)
+    xy_recipe_prep
   }
 
   # To load the prepared training data into a variable juice() is used.
   # It extracts the data from the xy_recipe object.
-  #xy_training <- recipes::juice(xy_recipe)
 
   # Number of predictors (if more than one should use standard linear regression)
-  # number_of_predictors <- sum(xy_recipe$var_info$role == "predictor")
-
 
   # Create and fit model. help(rand_forest)
   if (is.null(extremely_randomised_splitrule)) {
     mod_spec <-
       parsnip::rand_forest(mode = mode_rf, trees = trees, mtry = mtry, min_n = min_n) %>%
-      # parsnip::set_engine("ranger")
-      parsnip::set_engine("randomForest") #%>%
-      #parsnip::fit(y ~ ., data = xy_training)
+      parsnip::set_engine("randomForest")
 
     # Create Workflow (to know variable roles from recipes)
     wf <- workflows::workflow() %>%
@@ -222,14 +215,12 @@ fit_model_accuracy_rf <- function(object,
       workflows::add_recipe(xy_recipe)
 
     # Fit model
-    mod <-  parsnip::fit(wf, data = data_train)
-
+    mod <- parsnip::fit(wf, data = data_train)
   } else if (is.character(extremely_randomised_splitrule)) {
     mod_spec <-
       parsnip::rand_forest(mode = mode_rf) %>%
       parsnip::set_engine("ranger", splitrule = extremely_randomised_splitrule) %>%
-      parsnip::set_mode("classification") #%>%
-      #parsnip::fit(y ~ ., data = xy_training)
+      parsnip::set_mode("classification")
 
     # Create Workflow (to know variable roles from recipes)
     wf <- workflows::workflow() %>%
@@ -237,9 +228,7 @@ fit_model_accuracy_rf <- function(object,
       workflows::add_recipe(xy_recipe)
 
     # Fit model
-    mod <-  parsnip::fit(wf, data = data_train)
-
-
+    mod <- parsnip::fit(wf, data = data_train)
   }
 
   # Prepare the test data according to the recipe
@@ -248,17 +237,23 @@ fit_model_accuracy_rf <- function(object,
 
   # Apply model on new data
   holdout_pred_class <-
-    stats::predict(mod, xy_testing %>% dplyr::select(-y), type = c("class")) %>%
+    stats::predict(mod, xy_testing %>%
+                     dplyr::select(-y), type = c("class")) %>%
     dplyr::bind_cols(rsample::assessment(object) %>% dplyr::select(y, id_nr))
 
   holdout_pred <-
-    stats::predict(mod, xy_testing %>% dplyr::select(-y), type = c("prob")) %>%
+    stats::predict(mod, xy_testing %>%
+                     dplyr::select(-y), type = c("prob")) %>%
     dplyr::bind_cols(rsample::assessment(object) %>% dplyr::select(y, id_nr))
 
   holdout_pred$.pred_class <- holdout_pred_class$.pred_class
   class <- colnames(holdout_pred[2])
 
-  eval_measure_val <- select_eval_measure_val(eval_measure = eval_measure, holdout_pred = holdout_pred, truth = y, estimate = .pred_class, class = class)
+  eval_measure_val <- select_eval_measure_val(eval_measure = eval_measure,
+                                              holdout_pred = holdout_pred,
+                                              truth = y,
+                                              estimate = .pred_class,
+                                              class = class)
 
   # Sort output of RMSE, predictions and truth (observed y)
   output <- list(
@@ -345,7 +340,7 @@ tune_over_cost_rf <- function(object,
                               eval_measure,
                               extremely_randomised_splitrule) {
   if (!is.na(preprocess_PCA[1])) {
-    # Number of components or percent of variance to attain; min_halving; preprocess_PCA = c(0.9, 0.3); preprocess_PCA = NA
+    # Number of components or percent of variance to attain; min_halving;
     if (preprocess_PCA[1] == "min_halving") {
       num_features <- length(rsample::analysis(object)) - 1
       num_users <- nrow(rsample::analysis(object))
@@ -448,25 +443,34 @@ summarize_tune_results_rf <- function(object,
 #'
 #' @param x Word embeddings from textEmbed.
 #' @param y Categorical variable to predict.
-#' @param cv_method Cross-validation method to use within a pipeline of nested outer and inner loops of folds (see nested_cv in rsample).
-#' Default is using cv_folds in the outside folds and "validation_split" using rsample::validation_split in the inner loop to achieve a development and assessment
-#' set (note that for validation_split the inside_folds should be a proportion, e.g., inside_folds = 3/4); whereas "cv_folds" uses rsample::vfold_cv to achieve n-folds
-#' in both the outer and inner loops.
+#' @param cv_method Cross-validation method to use within a pipeline of nested outer and
+#' inner loops of folds (see nested_cv in rsample). Default is using cv_folds in the
+#' outside folds and "validation_split" using rsample::validation_split in the inner loop to
+#' achieve a development and assessment set (note that for validation_split the inside_folds
+#' should be a proportion, e.g., inside_folds = 3/4); whereas "cv_folds" uses rsample::vfold_cv
+#' to achieve n-folds in both the outer and inner loops.
 #' @param outside_folds Number of folds for the outer folds (default = 10).
 #' @param outside_strata_y Variable to stratify according (default "y"; can also set to NULL).
-#' @param outside_breaks The number of bins wanted to stratify a numeric stratification variable in the outer cross-validation loop.
+#' @param outside_breaks The number of bins wanted to stratify a numeric stratification variable
+#' in the outer cross-validation loop.
 #' @param inside_folds Number of folds for the inner folds (default = 3/4).
 #' @param inside_strata_y Variable to stratify according (default "y"; can also set to NULL).
-#' @param inside_breaks The number of bins wanted to stratify a numeric stratification variable in the inner cross-validation loop.
+#' @param inside_breaks The number of bins wanted to stratify a numeric stratification variable
+#' in the inner cross-validation loop.
 #' @param mode_rf Default is "classification" ("regression" is not supported yet).
-#' @param preprocess_step_center normalizes dimensions to have a mean of zero; default is set to TRUE. For more info see (step_center in recipes).
-#' @param preprocess_scale_center  normalize dimensions to have a standard deviation of one. For more info see (step_scale in recipes).
-#' @param preprocess_PCA Pre-processing threshold for PCA. Can select amount of variance to retain (e.g., .90 or as a grid c(0.80, 0.90)); or
-#' number of components to select (e.g., 10). Default is "min_halving", which is a function that selects the number of PCA components based on number
-#' of participants and feature (word embedding dimensions) in the data. The formula is:
+#' @param preprocess_step_center normalizes dimensions to have a mean of zero; default is set to TRUE.
+#' For more info see (step_center in recipes).
+#' @param preprocess_scale_center  normalize dimensions to have a standard deviation of one.
+#' For more info see (step_scale in recipes).
+#' @param preprocess_PCA Pre-processing threshold for PCA. Can select amount of variance to
+#' retain (e.g., .90 or as a grid c(0.80, 0.90)); or
+#' number of components to select (e.g., 10). Default is "min_halving", which is a function that
+#' selects the number of PCA components based on number of participants and feature (word embedding
+#' dimensions) in the data. The formula is:
 #' preprocess_PCA = round(max(min(number_features/2), number_participants/2), min(50, number_features))).
-#' @param extremely_randomised_splitrule default: "extratrees", which thus implement a random forest; can also select: NULL, "gini" or "hellinger"; if these are selected
-#' your mtry settings will be overridden (see Geurts et al. (2006) Extremely randomized trees for details; and see the ranger r-package
+#' @param extremely_randomised_splitrule default: "extratrees", which thus implement a random forest;
+#' can also select: NULL, "gini" or "hellinger"; if these are selected your mtry settings will
+#'  be overridden (see Geurts et al. (2006) Extremely randomized trees for details; and see the ranger r-package
 #' for details on implementations).
 #' @param mtry hyper parameter that may be tuned;  default:c(1, 20, 40),
 #' @param min_n hyper parameter that may be tuned; default: c(1, 20, 40)
@@ -474,24 +478,26 @@ summarize_tune_results_rf <- function(object,
 #' @param eval_measure Measure to evaluate the models in order to select the best hyperparameters default "roc_auc";
 #' see also "accuracy", "bal_accuracy", "sens", "spec", "precision", "kappa", "f_measure".
 #' @param model_description Text to describe your model (optional; good when sharing the model with others).
-#' @param multi_cores If TRUE it enables the use of multiple cores if the computer system allows for it (i.e., only on unix, not windows). Hence it
-#' makes the analyses considerably faster to run. Default is "multi_cores_sys_default", where it automatically uses TRUE for Mac and Linux and FALSE for Windows.
-#' @param save_output Option not to save all output; default "all". see also "only_results" and "only_results_predictions".
+#' @param multi_cores If TRUE it enables the use of multiple cores if the computer system allows for it (i.e.,
+#'  only on unix, not windows). Hence it makes the analyses considerably faster to run. Default is
+#'   "multi_cores_sys_default", where it automatically uses TRUE for Mac and Linux and FALSE for Windows.
+#' @param save_output Option not to save all output; default "all". see also "only_results" and
+#' "only_results_predictions".
 #' @param seed Set different seed.
 #' @param ... For example settings in yardstick::accuracy to set event_level (e.g., event_level = "second").
-#' @return A list with roc_curve_data, roc_curve_plot, truth and predictions, preprocessing_recipe, final_model, model_description
-#' chisq and fishers test as well as evaluation measures, e.g., including accuracy, f_meas and roc_auc (for details on
-#' these measures see the yardstick r-package documentation).
+#' @return A list with roc_curve_data, roc_curve_plot, truth and predictions, preprocessing_recipe,
+#' final_model, model_description chisq and fishers test as well as evaluation measures, e.g., including accuracy,
+#' f_meas and roc_auc (for details on these measures see the yardstick r-package documentation).
 #' @examples
 #' \donttest{
-#'results <- textTrainRandomForest(
-#'  wordembeddings4$harmonywords,
-#'  as.factor(Language_based_assessment_data_8$gender),
-#'  trees = c(1000, 1500),
-#'  mtry  = c(1), # this is short because of testing
-#'  min_n = c(1), # this is short because of testing
-#'  multi_cores = FALSE # This is FALSE due to CRAN testing and Windows machines.
-#')
+#' results <- textTrainRandomForest(
+#'   word_embeddings_4$harmonywords,
+#'   as.factor(Language_based_assessment_data_8$gender),
+#'   trees = c(1000, 1500),
+#'   mtry  = c(1), # this is short because of testing
+#'   min_n = c(1), # this is short because of testing
+#'   multi_cores = FALSE # This is FALSE due to CRAN testing and Windows machines.
+#' )
 #' }
 #' @seealso see \code{\link{textTrainLists}} \code{\link{textSimilarityTest}}
 #' @importFrom stats cor.test na.omit chisq.test fisher.test complete.cases
@@ -512,7 +518,7 @@ textTrainRandomForest <- function(x,
                                   outside_folds = 10,
                                   outside_strata_y = "y",
                                   outside_breaks = 4,
-                                  inside_folds = 3/4,
+                                  inside_folds = 3 / 4,
                                   inside_strata_y = "y",
                                   inside_breaks = 4,
                                   mode_rf = "classification",
@@ -588,7 +594,6 @@ textTrainRandomForest <- function(x,
 
     # Make one df rather then list.
     x1 <- dplyr::bind_cols(xlist)
-
   }
   ############ End for multiple word embeddings ############
   ##########################################################
@@ -609,35 +614,35 @@ textTrainRandomForest <- function(x,
 
 
   # Cross-Validation help(nested_cv) help(vfold_cv) help(validation_split)
-  if(cv_method == "cv_folds") {
+  if (cv_method == "cv_folds") {
     results_nested_resampling <- rlang::expr(rsample::nested_cv(xy,
-                                                                outside = rsample::vfold_cv(
-                                                                  v       = !!outside_folds,
-                                                                  repeats = 1,
-                                                                  strata  = !!outside_strata_y,
-                                                                  breaks  = !!outside_breaks
-                                                                ), #
-                                                                inside = rsample::vfold_cv(
-                                                                  v       = !!inside_folds,
-                                                                  repeats = 1,
-                                                                  strata  = !!inside_strata_y,
-                                                                  breaks  = !!inside_breaks
-                                                                )
+      outside = rsample::vfold_cv(
+        v = !!outside_folds,
+        repeats = 1,
+        strata = !!outside_strata_y,
+        breaks = !!outside_breaks
+      ), #
+      inside = rsample::vfold_cv(
+        v = !!inside_folds,
+        repeats = 1,
+        strata = !!inside_strata_y,
+        breaks = !!inside_breaks
+      )
     ))
   }
-  if(cv_method == "validation_split") {
+  if (cv_method == "validation_split") {
     results_nested_resampling <- rlang::expr(rsample::nested_cv(xy,
-                                                                outside = rsample::vfold_cv(
-                                                                  v       = !!outside_folds,
-                                                                  repeats = 1,
-                                                                  strata  = !!outside_strata_y,
-                                                                  breaks  = !!outside_breaks
-                                                                ), #
-                                                                inside = rsample::validation_split(
-                                                                  prop   = !!inside_folds,
-                                                                  strata = !!inside_strata_y,
-                                                                  breaks = !!inside_breaks
-                                                                )
+      outside = rsample::vfold_cv(
+        v = !!outside_folds,
+        repeats = 1,
+        strata = !!outside_strata_y,
+        breaks = !!outside_breaks
+      ), #
+      inside = rsample::validation_split(
+        prop = !!inside_folds,
+        strata = !!inside_strata_y,
+        breaks = !!inside_breaks
+      )
     ))
   }
 
@@ -695,9 +700,11 @@ textTrainRandomForest <- function(x,
 
 
   # Function to get the lowest eval_measure_val library(tidyverse)
-  if(eval_measure %in% c("accuracy" , "bal_accuracy", "sens", "spec", "precision", "kappa", "f_measure", "roc_auc", "rsq", "cor_test")) {
+  if (eval_measure %in% c("accuracy", "bal_accuracy", "sens", "spec",
+                          "precision", "kappa", "f_measure", "roc_auc",
+                          "rsq", "cor_test")) {
     bestParameters <- function(dat) dat[which.max(dat$eval_measure), ]
-  } else if (eval_measure == "rmse"){
+  } else if (eval_measure == "rmse") {
     bestParameters <- function(dat) dat[which.min(dat$eval_measure), ]
   }
 
@@ -749,41 +756,41 @@ textTrainRandomForest <- function(x,
       recipes::update_role(id_nr, new_role = "id variable") %>%
       recipes::update_role(-id_nr, new_role = "predictor") %>%
       recipes::update_role(y, new_role = "outcome") %>%
-      recipes::step_naomit(recipes::all_predictors(), skip = FALSE) #%>%
-      # recipes::step_BoxCox(recipes::all_predictors()) %>%
+      recipes::step_naomit(recipes::all_predictors(), skip = FALSE) # %>%
+    # recipes::step_BoxCox(recipes::all_predictors()) %>%
 
-   if (preprocess_step_center) {
-     final_recipe <- recipes::step_center(final_recipe, recipes::all_predictors())
-   }
-  if (preprocess_scale_center) {
-    final_recipe <- recipes::step_scale(final_recipe, recipes::all_predictors())
-   }
+    if (preprocess_step_center) {
+      final_recipe <- recipes::step_center(final_recipe, recipes::all_predictors())
+    }
+    if (preprocess_scale_center) {
+      final_recipe <- recipes::step_scale(final_recipe, recipes::all_predictors())
+    }
 
     # If preprocess_PCA is not NULL add PCA step with number of component of % of variance to retain specification
-    final_recipe <- final_recipe %>%
-      {
-        if (!is.na(preprocess_PCA[1])) {
-          if (preprocess_PCA[1] >= 1) {
-            recipes::step_pca(., recipes::all_predictors(), num_comp = statisticalMode(results_split_parameter$preprocess_PCA))
-          } else if (preprocess_PCA[1] < 1) {
-            recipes::step_pca(., recipes::all_predictors(), threshold = statisticalMode(results_split_parameter$preprocess_PCA))
-          } else {
-            .
-          }
+    final_recipe <- final_recipe %>% {
+      if (!is.na(preprocess_PCA[1])) {
+        if (preprocess_PCA[1] >= 1) {
+          recipes::step_pca(., recipes::all_predictors(),
+                            num_comp = statisticalMode(results_split_parameter$preprocess_PCA))
+        } else if (preprocess_PCA[1] < 1) {
+          recipes::step_pca(., recipes::all_predictors(),
+                            threshold = statisticalMode(results_split_parameter$preprocess_PCA))
         } else {
           .
         }
+      } else {
+        .
       }
+    }
     ######### More than one word embeddings as input
   } else {
-    V1 <- colnames(xy_all[1])
 
     final_recipe <- recipes::recipe(y ~ ., xy_all[0, ]) %>%
       recipes::update_role(id_nr, new_role = "id variable") %>%
       recipes::update_role(-id_nr, new_role = "predictor") %>%
       recipes::update_role(y, new_role = "outcome") %>%
-      recipes::step_naomit(recipes::all_predictors(), skip = TRUE) #%>%
-      # recipes::step_BoxCox(recipes::all_predictors()) %>%
+      recipes::step_naomit(recipes::all_predictors(), skip = TRUE) # %>%
+    # recipes::step_BoxCox(recipes::all_predictors()) %>%
 
     if (preprocess_step_center) {
       final_recipe <- recipes::step_center(final_recipe, recipes::all_predictors())
@@ -818,57 +825,64 @@ textTrainRandomForest <- function(x,
   # Creating new environment to keep saving size down
   # Creating recipe in another environment sto avoid saving unnecessarily large parts of the environment
   # when saving the object to rda, rds or Rdata.
-  # http://r.789695.n4.nabble.com/Model-object-when-generated-in-a-function-saves-entire-environment-when-saved-td4723192.html
-  recipe_save_small_size <- function(final_recipe, xy_all){
-
+  # http://r.789695.n4.nabble.com/Model-object-when-generated-
+  # in-a-function-saves-entire-environment-when-saved-td4723192.html
+  recipe_save_small_size <- function(final_recipe, xy_all) {
     env_final_recipe <- new.env(parent = globalenv())
     env_final_recipe$xy_all <- xy_all
     env_final_recipe$final_recipe <- final_recipe
 
     with(env_final_recipe, preprocessing_recipe_save <- suppressWarnings(recipes::prep(final_recipe,
-                                                                                       xy_all,
-                                                                                       retain = FALSE)))
+      xy_all,
+      retain = FALSE
+    )))
   }
   preprocessing_recipe_save <- recipe_save_small_size(final_recipe = final_recipe, xy_all = xy_all)
 
   # To load the prepared training data into a variable juice() is used.
   # It extracts the data from the xy_recipe object.
 
-   model_save_small_size <- function(xy_all, final_recipe, results_split_parameter, mode_rf){
-     env_final_model <- new.env(parent = globalenv())
-     env_final_model$xy_all <- xy_all
-     env_final_model$final_recipe <- final_recipe
+  model_save_small_size <- function(xy_all, final_recipe, results_split_parameter, mode_rf) {
+    env_final_model <- new.env(parent = globalenv())
+    env_final_model$xy_all <- xy_all
+    env_final_model$final_recipe <- final_recipe
 
-     #env_final_model$results_split_parameter <- results_split_parameter
+    env_final_model$trees_mode <- statisticalMode(results_split_parameter$trees)
+    env_final_model$mtry_mode <- statisticalMode(results_split_parameter$mtry)
+    env_final_model$min_n_mode <- statisticalMode(results_split_parameter$min_n)
 
-     env_final_model$trees_mode <- statisticalMode(results_split_parameter$trees)
-     env_final_model$mtry_mode <- statisticalMode(results_split_parameter$mtry)
-     env_final_model$min_n_mode <- statisticalMode(results_split_parameter$min_n)
+    env_final_model$mode_rf <- mode_rf
+    env_final_model$statisticalMode <- statisticalMode
+    env_final_model$`%>%` <- `%>%`
 
-     env_final_model$mode_rf <- mode_rf
-     env_final_model$statisticalMode <- statisticalMode
-     env_final_model$`%>%`  <-  `%>%`
+    with(
+      env_final_model,
 
-     with(env_final_model,
+      final_predictive_model_spec <-
+        parsnip::rand_forest(
+          mode = mode_rf,
+          trees = trees_mode,
+          mtry = mtry_mode,
+          min_n = min_n_mode
+        ) %>%
+        parsnip::set_engine("randomForest")
+    )
 
-          final_predictive_model_spec <-
-            parsnip::rand_forest(mode = mode_rf,
-                                 trees = trees_mode,
-                                 mtry = mtry_mode,
-                                 min_n = min_n_mode) %>%
-            parsnip::set_engine("randomForest"))
+    with(
+      env_final_model,
+      wf_final <- workflows::workflow() %>%
+        workflows::add_model(final_predictive_model_spec) %>%
+        workflows::add_recipe(final_recipe)
+    )
 
-     with(env_final_model,
-    wf_final <- workflows::workflow() %>%
-      workflows::add_model(final_predictive_model_spec) %>%
-      workflows::add_recipe(final_recipe))
+    with(
+      env_final_model,
+      # Fit model
+      final_predictive_model <- parsnip::fit(wf_final, data = xy_all)
+    )
+  }
 
-     with(env_final_model,
-    # Fit model
-    final_predictive_model <-  parsnip::fit(wf_final, data = xy_all))
-     }
-
-   final_predictive_model <- model_save_small_size(xy_all, final_recipe, results_split_parameter, mode_rf)
+  final_predictive_model <- model_save_small_size(xy_all, final_recipe, results_split_parameter, mode_rf)
 
 
 
@@ -891,8 +905,10 @@ textTrainRandomForest <- function(x,
   mode_rf_description <- paste("mode =", mode_rf)
   trees_description <- paste("trees in final model =", statisticalMode(results_split_parameter$trees))
   trees_fold_description <- paste("trees in each fold =", deparse(results_split_parameter$trees))
-  preprocess_PCA_description <- paste("preprocess_PCA in final model = ", statisticalMode(results_split_parameter$preprocess_PCA))
-  preprocess_PCA_fold_description <- paste("preprocess_PCA in each fold = ", deparse(results_split_parameter$preprocess_PCA))
+  preprocess_PCA_description <- paste("preprocess_PCA in final model = ",
+                                      statisticalMode(results_split_parameter$preprocess_PCA))
+  preprocess_PCA_fold_description <- paste("preprocess_PCA in each fold = ",
+                                           deparse(results_split_parameter$preprocess_PCA))
   eval_measure <- paste("eval_measure = ", eval_measure)
 
   preprocess_step_center <- paste("preprocess_step_center_setting = ", deparse(preprocess_step_center))
@@ -919,7 +935,9 @@ textTrainRandomForest <- function(x,
   # Getting time and date
   T2_textTrainRandomForest <- Sys.time()
   Time_textTrainRandomForest <- T2_textTrainRandomForest - T1_textTrainRandomForest
-  Time_textTrainRandomForest <- sprintf("Duration to train text: %f %s", Time_textTrainRandomForest, units(Time_textTrainRandomForest))
+  Time_textTrainRandomForest <- sprintf("Duration to train text: %f %s",
+                                        Time_textTrainRandomForest,
+                                        units(Time_textTrainRandomForest))
   Date_textTrainRandomForest <- Sys.time()
   time_date <- paste(Time_textTrainRandomForest,
     "; Date created: ", Date_textTrainRandomForest,
@@ -963,54 +981,67 @@ textTrainRandomForest <- function(x,
   ##########################################
 
   if (save_output == "all") {
-    final_results <- list(results_collected$roc_curve_data,
-                          results_collected$predy_y,
-                          preprocessing_recipe_save,
-                          final_predictive_model,
-                          results_collected$roc_curve_plot,
-                          model_description_detail,
-                          results_collected$fisher,
-                          results_collected$chisq,
-                          results_collected$results_collected)
-    names(final_results) <- c("roc_curve_data",
-                              "truth_predictions",
-                              "final_recipe",
-                              "final_model",
-                              "roc_curve_plot",
-                              "model_description",
-                              "fisher_test",
-                              "chisq",
-                              "results")
+    final_results <- list(
+      results_collected$roc_curve_data,
+      results_collected$predy_y,
+      preprocessing_recipe_save,
+      final_predictive_model,
+      results_collected$roc_curve_plot,
+      model_description_detail,
+      results_collected$fisher,
+      results_collected$chisq,
+      results_collected$results_collected
+    )
+    names(final_results) <- c(
+      "roc_curve_data",
+      "truth_predictions",
+      "final_recipe",
+      "final_model",
+      "roc_curve_plot",
+      "model_description",
+      "fisher_test",
+      "chisq",
+      "results"
+    )
   } else if (save_output == "only_results_predictions") {
-    final_results <- list(results_collected$roc_curve_data,
-                          results_collected$predy_y,
-                          results_collected$roc_curve_plot,
-                          model_description_detail,
-                          results_collected$fisher,
-                          results_collected$chisq,
-                          results_collected$results_collected)
-    names(final_results) <- c("roc_curve_data",
-                              "truth_predictions",
-                              "roc_curve_plot",
-                              "model_description",
-                              "fisher_test",
-                              "chisq",
-                              "results")
+    final_results <- list(
+      results_collected$roc_curve_data,
+      results_collected$predy_y,
+      results_collected$roc_curve_plot,
+      model_description_detail,
+      results_collected$fisher,
+      results_collected$chisq,
+      results_collected$results_collected
+    )
+    names(final_results) <- c(
+      "roc_curve_data",
+      "truth_predictions",
+      "roc_curve_plot",
+      "model_description",
+      "fisher_test",
+      "chisq",
+      "results"
+    )
   } else if (save_output == "only_results") {
-    final_results <- list(results_collected$roc_curve_data,
-                          results_collected$roc_curve_plot,
-                          model_description_detail,
-                          results_collected$fisher,
-                          results_collected$chisq,
-                          results_collected$results_collected)
-    names(final_results) <- c("roc_curve_data",
-                              "roc_curve_plot",
-                              "model_description",
-                              "fisher_test",
-                              "chisq",
-                              "results")
+    final_results <- list(
+      results_collected$roc_curve_data,
+      results_collected$roc_curve_plot,
+      model_description_detail,
+      results_collected$fisher,
+      results_collected$chisq,
+      results_collected$results_collected
+    )
+    names(final_results) <- c(
+      "roc_curve_data",
+      "roc_curve_plot",
+      "model_description",
+      "fisher_test",
+      "chisq",
+      "results"
+    )
   }
-  # Remove object to minimize model size when saved to rds; use this to check sizes: sort( sapply(ls(),function(x){object.size(get(x))}))
+  # Remove object to minimize model size when saved to rds; use this to
+  # check sizes: sort( sapply(ls(),function(x) {object.size(get(x))}))
   remove(x)
   remove(x1)
   remove(y)
