@@ -9,8 +9,8 @@ test_that("textSimilarity produces similarity scores", {
   skip_on_cran()
 
   similarity_scores <- textSimilarity(
-    wordembeddings4$harmonytexts,
-    wordembeddings4$satisfactiontexts
+    word_embeddings_4$harmonytexts,
+    word_embeddings_4$satisfactiontexts
   )
   expect_that(similarity_scores, is_a("numeric"))
 })
@@ -19,10 +19,10 @@ test_that("textSimilarity produces similarity scores", {
   skip_on_cran()
 
   # Example norm
-  harmonynorm <- wordembeddings4$harmonywords[1, ]
+  harmonynorm <- word_embeddings_4$harmonywords[1, ]
 
   similarity_norm_scores <- textSimilarityNorm(
-    wordembeddings4$harmonytext[1:2, ],
+    word_embeddings_4$harmonytext[1:2, ],
     harmonynorm
   )
 
@@ -32,8 +32,8 @@ test_that("textSimilarity produces similarity scores", {
 test_that("textSimilarityTest paired results in list with numeric output", {
   skip_on_cran()
 
-  test_diff_results <- textSimilarityTest(wordembeddings4$harmonytexts, wordembeddings4$satisfactiontexts,
-    method = "paired", Npermutations = 10, N_cluster_nodes = 1
+  test_diff_results <- textSimilarityTest(word_embeddings_4$harmonytexts, word_embeddings_4$satisfactiontexts,
+    method = "paired", Npermutations = 100, N_cluster_nodes = 1
   )
 
   expect_that(test_diff_results, is_a("list"))
@@ -43,16 +43,16 @@ test_that("textSimilarityTest paired results in list with numeric output", {
 test_that("textSimilarityTest paired results in list with numeric output", {
   skip_on_cran()
 
-  expect_error(textSimilarityTest(wordembeddings4$harmonytexts, wordembeddings4$satisfactiontexts[1:39, ],
-    method = "paired", Npermutations = 10, N_cluster_nodes = 1
+  expect_error(textSimilarityTest(word_embeddings_4$harmonytexts, word_embeddings_4$satisfactiontexts[1:39, ],
+    method = "paired", Npermutations = 100, N_cluster_nodes = 1
   ))
 })
 
 test_that("textSimilarityTest unpaired results in list with numeric output", {
   skip_on_cran()
 
-  test_diff_results <- textSimilarityTest(wordembeddings4$harmonytexts, wordembeddings4$satisfactiontexts,
-    method = "unpaired", Npermutations = 10, N_cluster_nodes = 1
+  test_diff_results <- textSimilarityTest(word_embeddings_4$harmonytexts, word_embeddings_4$satisfactiontexts,
+    method = "unpaired", Npermutations = 100, N_cluster_nodes = 1
   )
 
   expect_that(test_diff_results, is_a("list"))
@@ -63,12 +63,11 @@ test_that("textSimilarityTest unpaired results in list with numeric output", {
 test_that("textSimilarityTest unpaired results in list with numeric output", {
   skip_on_cran()
 
-  test_diff_results <- textSimilarityTest(wordembeddings4$harmonytexts, wordembeddings4$satisfactiontexts,
-                                          method = "unpaired", Npermutations = 10, N_cluster_nodes = 1,
-                                          output.permutations = FALSE
+  test_diff_results <- textSimilarityTest(word_embeddings_4$harmonytexts, word_embeddings_4$satisfactiontexts,
+    method = "unpaired", Npermutations = 100, N_cluster_nodes = 1,
+    output.permutations = FALSE
   )
 
   expect_that(test_diff_results, is_a("list"))
   expect_is(test_diff_results$p.value[[1]], "numeric")
 })
-
